## Youtube & Spotify Downloader

This library is a useful tool for downloading from **Youtube** and **Spotify**. Just create a **urls.txt** file on your **Desktop** and add the links you want to download. Run **py-dl** in your terminal and the library will automatically download and put them inside a new folder called **downloads** on your **Desktop**.

---

Disclaimer: Please note that this project is currently under development. Various tests are conducted to make it bug-free, but there is always the possibility of errors.

Created with ♥ and maintained by Sadra Shameli. All Rights Reserved.
